class Status:
    SKIPPED = "SKIPPED"
    FAILED = "FAILED"
    PENDING = "PENDING"
    RUNNING = "RUNNING"
    COMPLETED = "COMPLETED"
    RETRYING = "RETRYING"


class Queue:
    CORE = "core"
    EMS = "ems"
    SIERRA = "sierra"


class Tasks:
    SEND_VERSION = "send_version_to_core"
    UPDATE_TASK_STATUS = "update_task_status"
    UPDATE_TASK_VALUES = "update_task_values"
    MODEL_UPDATE = "component_model_update"



COMPONENT_KEY = "linker"


class Task:
    BASE = "base_linker_task"
    VECTORIZE = "vectorize_text"
    LINK_AND_NORMALIZE = "core_linker_with_normalization"
    VECTORIZE_AND_INDEX = "core_vectorize_and_index"
    RECEIVE_LINK_AND_NORMALIZE = "receive_link_and_normalize"


class Queue:
    LINKER = "linker"
    VECTORIZER = "vectorizer"
